# ProjectTriggerResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**name** | **str** |  | [optional] 
**project_id** | **str** |  | [optional] 
**is_disabled** | **bool** |  | [optional] 
**filter** | [**TriggerFilterResource**](TriggerFilterResource.md) |  | [optional] 
**action** | [**TriggerActionResource**](TriggerActionResource.md) |  | [optional] 
**space_id** | **str** |  | [optional] 
**last_modified_on** | **datetime** |  | [optional] 
**last_modified_by** | **str** |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


